==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TemplateSectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata } from "./TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata";
import { SectionHeaderDescriptionMetadata } from "./SectionHeaderDescriptionMetadata";
import { TemplateSectionHeaderDescription } from "./TemplateSectionHeaderDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateSectionHeaderDescriptionMetadata, _super);
    function TemplateSectionHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderDescriptionMetadata.a == null) {
            TemplateSectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderDescriptionMetadata.c(TemplateSectionHeaderDescriptionMetadata.a);
        }
        if (a.g(TemplateSectionHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(TemplateSectionHeaderDescriptionMetadata.a);
        TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d(a);
    };
    TemplateSectionHeaderDescriptionMetadata.c = function (a) {
        SectionHeaderDescriptionMetadata.c(a);
        a.item("CellUpdatingRef", "EventRef::cellUpdating");
    };
    TemplateSectionHeaderDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderDescriptionMetadata.b(a);
        a.u("TemplateSectionHeader", function () { return new TemplateSectionHeaderDescription(); });
        a.t("TemplateSectionHeader", TemplateSectionHeaderDescriptionMetadata.a);
    };
    TemplateSectionHeaderDescriptionMetadata.$t = markType(TemplateSectionHeaderDescriptionMetadata, 'TemplateSectionHeaderDescriptionMetadata');
    TemplateSectionHeaderDescriptionMetadata.a = null;
    return TemplateSectionHeaderDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TemplateSectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata } from "./TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata";
import { SectionHeaderDescriptionMetadata } from "./SectionHeaderDescriptionMetadata";
import { TemplateSectionHeaderDescription } from "./TemplateSectionHeaderDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateSectionHeaderDescriptionMetadata, _super);
    function TemplateSectionHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderDescriptionMetadata.a == null) {
            TemplateSectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderDescriptionMetadata.c(TemplateSectionHeaderDescriptionMetadata.a);
        }
        if (a.j(TemplateSectionHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateSectionHeaderDescriptionMetadata.a);
        TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d(a);
    };
    TemplateSectionHeaderDescriptionMetadata.c = function (a) {
        SectionHeaderDescriptionMetadata.c(a);
        a.item("CellUpdatingRef", "EventRef::cellUpdating");
    };
    TemplateSectionHeaderDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderDescriptionMetadata.b(a);
        a.aa("TemplateSectionHeader", function () { return new TemplateSectionHeaderDescription(); });
        a.z("TemplateSectionHeader", TemplateSectionHeaderDescriptionMetadata.a);
    };
    TemplateSectionHeaderDescriptionMetadata.$t = markType(TemplateSectionHeaderDescriptionMetadata, 'TemplateSectionHeaderDescriptionMetadata');
    TemplateSectionHeaderDescriptionMetadata.a = null;
    return TemplateSectionHeaderDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderDescriptionMetadata };
